package com.fuzamei.web;

import java.io.IOException;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.validation.Valid;

import org.springframework.validation.BindingResult;
import org.springframework.validation.FieldError;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fuzamei.entity.User;
import com.fuzamei.service.UserService;
import com.fuzamei.utils.JSONUtil;

/**
 * 
* <b>Description:用户模块Action层</b><br> 
* @Note
* <b>Author:maamin
* @version 1.0
* @Note
* <b>ProjectName:</b> ccb_fund_trusteeship
* <br><b>PackageName:</b> com.fuzamei.web
* <br><b>ClassName:</b> UserAction
* <br><b>Date:</b> 2017年12月25日 上午10:16:00
 */
@RestController
@RequestMapping(value = "/user")
public class UserAction {
	@Resource(name = "userService")
	private UserService userService;
	/**
	 * 
	* <b>Description:用户登录方法</b><br> 
	* @param data
	* @return
	* @Note
	* <b>Author:maamin
	* <br><b>Date:</b> 2017年12月25日 上午10:18:07
	* <br><b>Version:</b> 1.0
	 */
	@RequestMapping(value = "/login",method = RequestMethod.POST)
	public Map<String,Object> login(@Validated @RequestBody User user,BindingResult result){
		System.out.println("进入用户登录login方法……"+user.getUser_name());
		Map<String,Object> resultMap = new LinkedHashMap<String,Object>();	//存放最终返回结果
		try {
			if(result.hasErrors()){
				List<FieldError> errors = result.getFieldErrors();
				for(FieldError fe : errors){
					String errorField = fe.getField();	//得到出错的字段
					String errorMessage = fe.getDefaultMessage();
					System.out.println("----出错的字段："+errorField+">>>字段错误信息："+errorMessage);
				}
				System.out.println("未通过校验……"+result.getErrorCount());
			}
			resultMap = userService.login(user);
		} catch (Exception e) {
			// TODO: handle exception
			e.printStackTrace();
			resultMap = JSONUtil.getJsonMap(12431, false, "用户登录失败", null);
		}
		System.out.println("用户登录login方式结束……");
		return resultMap;
	}
	/**
	 * 
	* <b>Description:初始化创建所有用户信息</b><br> 
	* @return
	* @Note
	* <b>Author:maamin
	* <br><b>Date:</b> 2017年12月25日 上午10:25:24
	* <br><b>Version:</b> 1.0
	 */
	@RequestMapping(value = "/initUserList",method = RequestMethod.GET)
	public Map<String,Object> initUserList(){
		System.out.println("初始化创建用户列表……");
		return userService.initUserList();
	}
	/**
	 * 
	* <b>Description:添加用户信息</b><br> 
	* @param data
	* @return
	* @Note
	* <b>Author:maamin
	* <br><b>Date:</b> 2017年12月25日 下午2:58:44
	* <br><b>Version:</b> 1.0
	 */
	@RequestMapping(value = "/addUser",method = RequestMethod.POST)
	public Map<String,Object> addUser(@RequestBody String data){
		System.out.println("添加用户……");
		Map<String,Object> resultMap = new HashMap<String,Object>();
		Map<String,Object> paramMap = new HashMap<String,Object>();
		User user = null;
		ObjectMapper objMapper = new ObjectMapper();
		try {
			user = objMapper.readValue(data, User.class);
		} catch (JsonParseException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			resultMap = JSONUtil.getJsonMap(12431, false, "json解析错误", null);
		} catch (JsonMappingException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			resultMap = JSONUtil.getJsonMap(12431, false, "参数错误", null);
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		//参数判断
//		if(()||()){
//			
//		}
		
		
		
		return resultMap;
	}
}
